@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-embed-find.c,v 1.6 2006/09/13 11:34:13 chpe Exp $
+ *  $Id: ephy-embed-find.c 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "config.h"
@@ -67,15 +67,17 @@ ephy_embed_find_find (EphyEmbedFind *find,
  * ephy_embed_find_find_again:
  * @embed: an #EphyEmbedFind
  * @forward %TRUE to search forwards in the document
+ * @links_only: whether to only search the text in links
  *
  * Return value: whether a match was found
  **/
 EphyEmbedFindResult
 ephy_embed_find_find_again (EphyEmbedFind *find,
-			    gboolean forward)
+			    gboolean forward,
+			    gboolean links_only)
 {
 	EphyEmbedFindIface *iface = EPHY_EMBED_FIND_GET_IFACE (find);
-	return iface->find_again (find, forward);
+	return iface->find_again (find, forward, links_only);
 }
 
 void
