@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GeckoFormSigningDialog.cpp 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id: GeckoFormSigningDialog.cpp 7166 2007-07-15 10:19:27Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -45,7 +45,7 @@
 
 #include "GeckoFormSigningDialog.h"
 
-#define LITERAL(s) NS_REINTERPRET_CAST(const nsAString::char_type*, NS_L(s))
+#define LITERAL(s) reinterpret_cast<const nsAString::char_type*>(NS_L(s))
 
 NS_IMPL_ISUPPORTS1 (GeckoFormSigningDialog,
 		    nsIFormSigningDialog)
