@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-history-window.c,v 1.106 2006/08/07 20:49:51 chpe Exp $
+ *  $Id: ephy-history-window.c 7108 2007-07-01 14:04:43Z jhaitsma $
  */
 
 #include "config.h"
@@ -67,6 +67,8 @@
 #include "ephy-node-common.h"
 #include "ephy-node-view.h"
 #include "ephy-bookmarks-ui.h"
+#include "ephy-prefs.h"
+#include "ephy-gui.h"
 
 static const GtkTargetEntry page_drag_types [] =
 {
@@ -173,10 +175,7 @@ static const GtkActionEntry ephy_history_ui_entries [] = {
 	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
 	  N_("Open the selected history link in a new tab"),
 	  G_CALLBACK (cmd_open_bookmarks_in_tabs) },
-	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
-	  N_("Delete the selected history link"),
-	  G_CALLBACK (cmd_delete) },
-	{ "BookmarkLink", STOCK_ADD_BOOKMARK, N_("Add _Bookmark..."), "<control>D",
+	{ "BookmarkLink", STOCK_ADD_BOOKMARK, N_("Add _Bookmark…"), "<control>D",
 	  N_("Bookmark the selected history link"),
 	  G_CALLBACK (cmd_bookmark_link) },
 	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
@@ -193,7 +192,10 @@ static const GtkActionEntry ephy_history_ui_entries [] = {
 	{ "Paste", GTK_STOCK_PASTE, N_("_Paste"), "<control>V",
 	  N_("Paste the clipboard"),
 	  G_CALLBACK (cmd_paste) },
-	{ "SelectAll", NULL, N_("Select _All"), "<control>A",
+	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), "<control>T",
+	  N_("Delete the selected history link"),
+	  G_CALLBACK (cmd_delete) },
+	{ "SelectAll", GTK_STOCK_SELECT_ALL, N_("Select _All"), "<control>A",
 	  N_("Select all history links or text"),
 	  G_CALLBACK (cmd_select_all) },
 	{ "Clear", GTK_STOCK_CLEAR, N_("Clear _History"), NULL,
@@ -204,7 +206,7 @@ static const GtkActionEntry ephy_history_ui_entries [] = {
 	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
 	  N_("Display history help"),
 	  G_CALLBACK (cmd_help_contents) },
-	{ "HelpAbout", GNOME_STOCK_ABOUT, N_("_About"), NULL,
+	{ "HelpAbout", GTK_STOCK_ABOUT, N_("_About"), NULL,
 	  N_("Display credits for the web browser creators"),
 	  G_CALLBACK (window_cmd_help_about) },
 };
@@ -257,6 +259,9 @@ confirmation_dialog_construct (EphyHistoryWindow *editor)
 		(GTK_MESSAGE_DIALOG (dialog),
 		 _("Clearing the browsing history will cause all"
 		   " history links to be permanently deleted."));
+
+	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (editor)),
+				     GTK_WINDOW (dialog));
 	
 	button = gtk_button_new_with_label (_("Cl_ear"));
 	image = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON);
@@ -268,7 +273,7 @@ confirmation_dialog_construct (EphyHistoryWindow *editor)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Clear History"));
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (confirmation_dialog_response_cb),
@@ -471,6 +476,8 @@ cmd_delete (GtkAction *action,
 		{
 			ephy_node_view_remove (EPHY_NODE_VIEW (editor->priv->sites_view));
 		}
+		
+		g_list_free (selected);
 	}
 }
 
@@ -560,7 +567,7 @@ ephy_history_window_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyHistoryWindowClass),
 			NULL,
@@ -662,6 +669,7 @@ ephy_history_window_update_menu (EphyHistoryWindow *editor)
 	gboolean cut, copy, paste, select_all;
 	gboolean pages_focus, pages_selection, single_page_selected;
 	gboolean delete, bookmark_page;
+	gboolean bookmarks_locked;
 	int num_pages_selected;
 	GtkActionGroup *action_group;
 	GtkAction *action;
@@ -716,7 +724,8 @@ ephy_history_window_update_menu (EphyHistoryWindow *editor)
 	open_in_window = (pages_focus && pages_selection);
 	open_in_tab = (pages_focus && pages_selection);
         delete = (pages_focus && pages_selection);
-	bookmark_page = (pages_focus && single_page_selected);
+	bookmarks_locked = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING);
+	bookmark_page = (pages_focus && single_page_selected) && !bookmarks_locked;
 
 	action_group = editor->priv->action_group;
 	action = gtk_action_group_get_action (action_group, "OpenInWindow");
@@ -738,6 +747,7 @@ ephy_history_window_update_menu (EphyHistoryWindow *editor)
 	gtk_action_set_sensitive (action, delete);
 	action = gtk_action_group_get_action (action_group, "BookmarkLink");
 	gtk_action_set_sensitive (action, bookmark_page);
+
 }
 
 static void
@@ -1180,6 +1190,8 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 	GtkActionGroup *action_group;
 	int url_col_id, title_col_id, details_value;
 
+	ephy_gui_ensure_window_group (GTK_WINDOW (editor));
+
 	gtk_window_set_title (GTK_WINDOW (editor), _("History"));
 	gtk_window_set_icon_name (GTK_WINDOW (editor), EPHY_STOCK_HISTORY);
 
