@@ -15,16 +15,15 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-statusbar.h,v 1.12 2006/12/03 19:05:19 chpe Exp $
+ *  $Id: ephy-statusbar.h 7127 2007-07-10 11:56:30Z chpe $
  */
 
 #ifndef EPHY_STATUSBAR_H
 #define EPHY_STATUSBAR_H
 
 #include <gtk/gtkstatusbar.h>
-#include <gtk/gtktooltips.h>
 
 G_BEGIN_DECLS
 
@@ -43,9 +42,6 @@ struct _EphyStatusbar
 {
         GtkStatusbar parent;
 
-	/*< public >*/
-	GtkTooltips *tooltips;
-
 	/*< private >*/
         EphyStatusbarPrivate *priv;
 };
@@ -62,8 +58,6 @@ GType         ephy_statusbar_get_type			(void);
 
 GtkWidget    *ephy_statusbar_new			(void);
 
-GtkTooltips  *ephy_statusbar_get_tooltips		(EphyStatusbar *statusbar);
-
 GtkWidget    *ephy_statusbar_get_security_frame		(EphyStatusbar *statusbar);
 
 void	      ephy_statusbar_set_caret_mode		(EphyStatusbar *statusbar,
